import { renderless, api } from '@opentinyvue/vue-renderless/numeric/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import { RepeatClick } from '@opentinyvue/vue-directive';
import { iconChevronDown, iconChevronUp, iconMinus, iconPlus } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var classes = {
  "numeric": "relative flex items-center w-full h-7 text-sm bg-color-bg-1 leading-none",
  "numeric_display_none": "hidden",
  "numeric_size": "sm:w-full sm:h-7 sm:text-sm",
  "numeric_medium": "sm:w-full sm:h-8 sm:text-sm",
  "numeric_decrease": "absolute z-10 text-center cursor-pointer left-0 flex items-center justify-center bg-color-bg-3 active:bg-color-border-separator focus:bg-border-separator sm:bg-inherit sm:active:bg-inherit sm:focus:bg-inherit w-7 h-full leading-7 border-r-0.5 border-color-border-separator rounded-l sm:border-0",
  "numeric_increase": "absolute z-10 text-center cursor-pointer right-0 flex items-center justify-center bg-color-bg-3 active:bg-color-border-separator focus:bg-border-separator sm:bg-inherit sm:active:bg-inherit sm:focus:bg-inherit w-7 h-full leading-7 border-l-0.5 border-color-border-separator rounded-r sm:border-0",
  "numeric_crease_disabled": "bg-color-bg-4 active:bg-color-bg-4 focus:bg-color-bg-4",
  "numeric_svg": "sm:w-4 sm:h-4 w-3.5 h-3.5 inline-block fill-color-icon-primary sm:hover:fill-color-brand-hover sm:active:fill-color-brand-active sm:focus:fill-color-brand-active",
  "numeric_svg_disabled": "fill-color-text-disabled cursor-not-allowed",
  "numeric_svg_size": "sm:w-7 sm:leading-7 sm:text-xs",
  "numeric_svg_medium": "sm:w-8 sm:leading-8 sm:text-sm",
  "numeric_input": "w-full block leading-3",
  "numeric_input-medium-unit": "sm:px-3 px-2 sm:w-full",
  "numeric_input-medium-num": "sm:px-8 px-9 sm:w-full",
  "numeric_input-default-unit": "px-2 sm:w-full",
  "numeric_input-default-num": "px-8 sm:px-9 sm:w-full",
  "numeric_input-active": "border-0.5 sm:border border-solid rounded border-color-border-separator sm:border-color-border text-color-text-primary",
  "numeric_input-disabled": "bg-inherit sm:bg-color-bg-6 sm:[&_input]:bg-transparent cursor-not-allowed sm:border border-0.5 border-solid rounded border-color-border-separator text-color-text-disabled sm:text-color-text-secondary",
  "numeric_input_inner": "w-full z-10 leading-7 sm:text-sm inline-block overflow-hidden outline-0 bg-color-bg-1",
  "numeric-text-center": "text-center",
  "numeric-text-left": "text-left",
  "numeric_input_inner_size": "leading-7 text-sm",
  "numeric_input_inner_medium": "sm:leading-8 text-sm sm:text-sm",
  "numeric_input_inner_disabled": "bg-color-bg-1 sm:bg-color-bg-6"
};
var __vue2_script = defineComponent({
  directives: directive({
    // 待整改
    repeatClick: {
      bind: RepeatClick
    }
  }),
  components: {
    IconChevronDown: iconChevronDown(),
    IconChevronUp: iconChevronUp(),
    IconMinus: iconMinus(),
    IconPlus: iconPlus()
  },
  props: [].concat(props, ["step", "tabindex", "stepStrictly", "max", "min", "modelValue", "disabled", "size", "controls", "controlsPosition", "name", "label", "placeholder", "precision", "circulate", "mouseWheel", "validateEvent", "allowEmpty", "emptyValue", "format", "unit", "stringMode", "holdZero", "plugin", "modelTruncation", "strictInput", "hideUnit", "unitCenter", "displayOnly", "changeCompat"]),
  emits: ["update:modelValue", "change", "blur", "focus"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api,
      classes
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "w-auto",
    class: _vm.state.isDisplayOnly ? "" : "flex items-center",
    attrs: {
      "data-tag": "tiny-numeric"
    }
  }, [_c("div", {
    class: _vm.m(_vm.gcls("numeric"), _vm.state.inputSize === "medium" ? _vm.gcls("numeric_medium") : _vm.gcls("numeric_size"), _vm.state.inputDisabled ? _vm.gcls("numeric_input-disabled") : _vm.gcls("numeric_input-active"), _vm.state.isDisplayOnly ? _vm.gcls("numeric_display_none") : ""),
    attrs: {
      "data-tag": "tiny-numeric-main"
    },
    on: {
      "dragstart": function dragstart($event) {
        $event.preventDefault();
      },
      "&mousewheel": function mousewheel($event) {
        return _vm.mouseEvent.apply(null, arguments);
      }
    }
  }, [_vm.controls ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    class: _vm.m(_vm.gcls("numeric_decrease"), _vm.state.inputSize === "medium" ? _vm.gcls("numeric_svg_medium") : _vm.gcls("numeric_svg_size"), _vm.state.minDisabled || _vm.state.inputDisabled ? _vm.gcls("numeric_crease_disabled") : ""),
    attrs: {
      "data-tag": "tiny-numeric-decrease",
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.decrease.apply(null, arguments);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-down" : "icon-minus", {
    tag: "component",
    class: _vm.m(_vm.state.minDisabled || _vm.state.inputDisabled ? _vm.gcls("numeric_svg_disabled") : _vm.gcls("numeric_svg"))
  })], 1) : _vm._e(), _vm.controls ? _c("div", {
    class: ["sm:w-px sm:h-4 sm:bg-color-text-disabled sm:absolute", _vm.state.inputSize === "medium" ? "sm:left-8" : "sm:left-7"],
    attrs: {
      "data-tag": "tiny-numeric-controls"
    }
  }) : _vm._e(), _vm.controls ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    class: _vm.m(_vm.gcls("numeric_increase"), _vm.state.inputSize === "medium" ? _vm.gcls("numeric_svg_medium") : _vm.gcls("numeric_svg_size"), _vm.state.minDisabled || _vm.state.inputDisabled ? _vm.gcls("numeric_crease_disabled") : ""),
    attrs: {
      "data-tag": "numeric-increase",
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.increase.apply(null, arguments);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-up" : "icon-plus", {
    tag: "component",
    class: _vm.state.maxDisabled || _vm.state.inputDisabled ? _vm.gcls("numeric_svg_disabled") : _vm.gcls("numeric_svg")
  })], 1) : _vm._e(), _vm.controls ? _c("div", {
    class: ["sm:w-px sm:h-4 sm:bg-color-text-disabled sm:absolute", _vm.state.inputSize === "medium" ? "sm:right-8" : "sm:right-7"],
    attrs: {
      "data-tag": "tiny-numeric-controls"
    }
  }) : _vm._e(), _c("div", {
    class: _vm.m(_vm.gcls("numeric_input-" + (_vm.state.inputSize === "medium" ? "medium" : "default") + "-" + (_vm.controls ? "num" : "unit")))
  }, [_c("input", {
    ref: "input",
    class: _vm.m(_vm.gcls("numeric_input_inner"), _vm.gcls("numeric-text-" + (_vm.controls ? "center" : "left")), _vm.state.inputSize === "medium" ? _vm.gcls("numeric_input_inner_medium") : _vm.gcls("numeric_input_inner_size"), _vm.state.inputDisabled ? _vm.gcls("numeric_input_inner_disabled") : _vm.gcls("numeric_input_inner_default")),
    attrs: {
      "tabindex": _vm.tabindex,
      "disabled": _vm.state.inputDisabled,
      "placeholder": _vm.placeholder,
      "max": _vm.max,
      "min": _vm.min,
      "name": _vm.name,
      "aria-label": _vm.label
    },
    domProps: {
      "value": _vm.state.displayValue
    },
    on: {
      "keydown": [function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "up", 38, $event.key, ["Up", "ArrowUp"])) return null;
        $event.preventDefault();
        return _vm.increase.apply(null, arguments);
      }, function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "down", 40, $event.key, ["Down", "ArrowDown"])) return null;
        $event.preventDefault();
        return _vm.decrease.apply(null, arguments);
      }],
      "blur": _vm.handleBlur,
      "focus": _vm.handleFocus,
      "compositionend": _vm.handleInput,
      "input": _vm.handleInput,
      "change": _vm.handleInputChange
    }
  })])]), _vm.state.isDisplayOnly ? _c("div", {
    staticClass: "sm:leading-normal text-color-text-primary",
    class: _vm.state.inputSize !== "mini" ? "text-sm" : "text-xs",
    attrs: {
      "data-tag": "numeric-display-only"
    }
  }, [_c("span", [_vm._v(_vm._s(_vm.state.displayOnlyText))]), _vm.unit && !_vm.hideUnit ? _c("span", {
    staticClass: "ml-2"
  }, [_vm._v(_vm._s(_vm.unit))]) : _vm._e()]) : _vm._e(), _vm.unit && !_vm.hideUnit && !_vm.state.isDisplayOnly ? _c("div", {
    class: ["h-0 right-0 flex text-xs sm:text-sm items-center shrink-0", _vm.unit ? "ml-2" : ""],
    attrs: {
      "data-tag": "numeric-unit"
    }
  }, [_vm._v(" " + _vm._s(_vm.unit) + " ")]) : _vm._e()]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
