import { renderless, api } from '@opentinyvue/vue-renderless/numeric/vue';
import { defineComponent, directive, props, setup } from '@opentinyvue/vue-common';
import { RepeatClick } from '@opentinyvue/vue-directive';
import { iconChevronDown, iconChevronUp, iconMinus, iconPlus } from '@opentinyvue/vue-icon';
import '@opentinyvue/vue-theme/numeric/index.css';
import FilterPanel from '@opentinyvue/vue-filter-panel';
import Radio from '@opentinyvue/vue-radio';
import RadioGroup from '@opentinyvue/vue-radio-group';
import Tag from '@opentinyvue/vue-tag';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  directives: directive({
    repeatClick: {
      bind: RepeatClick
    }
  }),
  components: {
    IconChevronDown: iconChevronDown(),
    IconChevronUp: iconChevronUp(),
    IconMinus: iconMinus(),
    IconPlus: iconPlus(),
    TinyFilterPanel: FilterPanel,
    TinyRadio: Radio,
    TinyRadioGroup: RadioGroup,
    TinyTag: Tag
  },
  props: [].concat(props, ["step", "tabindex", "stepStrictly", "max", "min", "modelValue", "disabled", "size", "controls", "controlsPosition", "name", "label", "placeholder", "precision", "circulate", "mouseWheel", "validateEvent", "allowEmpty", "emptyValue", "format", "unit", "stringMode", "holdZero", "plugin", "modelTruncation", "strictInput", "hideUnit", "unitCenter", "displayOnly", "showLeft", "showEmptyValue", "title", "shape", "tip", "clearable", "filter", "blank", "changeCompat"]),
  emits: ["update:modelValue", "change", "blur", "focus", "paste-error", "filter-change", "clear"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    class: ["tiny-numeric", _vm.state.inputSize ? "tiny-numeric--" + _vm.state.inputSize : "", {
      "is-disabled": _vm.state.inputDisabled
    }, {
      "is-without-controls": !_vm.controls || _vm.unit && _vm.hideUnit
    }, {
      "is-controls-right": _vm.state.controlsAtRight
    }, {
      "is-display-only": _vm.state.isDisplayOnly
    }],
    on: {
      "dragstart": function dragstart($event) {
        $event.preventDefault();
      },
      "mousewheel": function mousewheel($event) {
        $event.preventDefault();
        return _vm.mouseEvent.apply(null, arguments);
      }
    }
  }, [_vm.shape === "filter" ? _c("div", [_c("tiny-filter-panel", {
    ref: "filterPanel",
    attrs: {
      "label": _vm.title,
      "value": _vm.state.filterValue,
      "tip": _vm.tip,
      "disabled": _vm.disabled,
      "clearable": _vm.clearable,
      "blank": _vm.blank
    },
    on: {
      "handle-clear": _vm.handleClear
    }
  }, [_vm.shape === "filter" && _vm.filter ? _c("div", {
    staticClass: "tiny-numeric__popover-filter-content"
  }, [_c("tiny-radio-group", {
    on: {
      "change": _vm.handleChange
    },
    model: {
      value: _vm.state.radioVal,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "radioVal", $$v);
      },
      expression: "state.radioVal"
    }
  }, _vm._l(_vm.state.filterMenu, function(item, index) {
    return _c("tiny-radio", {
      key: index,
      staticClass: "popover-filter-botton",
      attrs: {
        "label": _vm.t(item)
      }
    }, [_c("tiny-tag", {
      attrs: {
        "size": "mini"
      }
    }, [_vm._v(_vm._s(_vm.t(item)))])], 1);
  }), 1)], 1) : _vm._e(), _c("div", {
    class: ["tiny-numeric", _vm.state.inputSize ? "tiny-numeric--" + _vm.state.inputSize : "", {
      "is-disabled": _vm.state.inputDisabled
    }, {
      "is-without-controls": !_vm.state.controls || _vm.unit && _vm.hideUnit
    }, {
      "is-controls-right": _vm.state.controlsAtRight
    }, {
      "is-display-only": _vm.state.isDisplayOnly
    }, {
      "is-filter": _vm.shape === "filter"
    }],
    attrs: {
      "data-tag": "tiny-numeric-filter"
    },
    on: {
      "dragstart": function dragstart($event) {
        $event.preventDefault();
      },
      "&mousewheel": function mousewheel($event) {
        return _vm.mouseEvent.apply(null, arguments);
      }
    }
  }, [_vm.state.controls && !_vm.unit ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    staticClass: "tiny-numeric__decrease",
    class: {
      "is-disabled": _vm.state.minDisabled
    },
    attrs: {
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.decrease.apply(null, arguments);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-down" : "icon-minus", {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e(), _vm.state.controls && !_vm.unit ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    staticClass: "tiny-numeric__increase",
    class: {
      "is-disabled": _vm.state.maxDisabled
    },
    attrs: {
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.increase.apply(null, arguments);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-up" : "icon-plus", {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e(), _vm.unit && !_vm.hideUnit ? _c("div", {
    staticClass: "tiny-numeric__unit"
  }, [_vm._v(" " + _vm._s(_vm.unit) + " ")]) : _vm._e(), _c("div", {
    class: ["tiny-numeric__input", {
      "tiny-numeric__read-only": _vm.state.isDisplayOnly
    }, _vm.state.inputSize ? "tiny-input-" + _vm.state.inputSize : "", _vm.state.inputDisabled ? "is-disabled" : "", {
      "has-unit": _vm.unit && !_vm.hideUnit
    }, {
      "text-align-left": _vm.unit && !_vm.unitCenter
    }, {
      "tiny-numeric__controls-position": _vm.controlsPosition
    }]
  }, [_c("span", {
    staticClass: "tiny-numeric-display-only"
  }, [_vm.state.isDisplayOnly ? _c("span", {
    staticClass: "tiny-numeric-display-only__content"
  }, [_c("span", {
    staticClass: "tiny-numeric-display-only__value"
  }, [_vm._v(_vm._s(_vm.state.displayOnlyText))]), _vm.unit && !_vm.hideUnit && _vm.state.currentValue ? _c("span", {
    staticClass: "tiny-numeric-display-only__unit"
  }, [_vm._v(_vm._s(_vm.unit))]) : _vm.unit && !_vm.hideUnit ? _c("span", [_vm._v(_vm._s(_vm.unit))]) : _vm._e()]) : _vm._e(), _c("input", {
    ref: "input",
    class: ["tiny-numeric__input-inner", {
      "tiny-numeric__show-left": !_vm.state.controls && (_vm.showLeft || _vm.shape === "filter")
    }],
    attrs: {
      "tabindex": _vm.tabindex,
      "placeholder": _vm.placeholder,
      "max": _vm.max,
      "min": _vm.min,
      "name": _vm.name,
      "aria-label": _vm.label
    },
    domProps: {
      "value": _vm.state.displayValue
    },
    on: {
      "keydown": [function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "up", 38, $event.key, ["Up", "ArrowUp"])) return null;
        $event.preventDefault();
        return _vm.increase.apply(null, arguments);
      }, function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "down", 40, $event.key, ["Down", "ArrowDown"])) return null;
        $event.preventDefault();
        return _vm.decrease.apply(null, arguments);
      }],
      "blur": _vm.handleBlur,
      "focus": _vm.handleFocus,
      "input": _vm.handleInput,
      "change": _vm.handleInputChange
    }
  })])])])])], 1) : _c("div", {
    staticClass: "tiny-numeric-base",
    attrs: {
      "data-tag": "tiny-numeric-base"
    }
  }, [_vm.controls && !_vm.unit ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.decrease,
      expression: "decrease"
    }],
    staticClass: "tiny-numeric__decrease",
    class: {
      "is-disabled": _vm.state.minDisabled
    },
    attrs: {
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.decrease.apply(null, arguments);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-down" : "icon-minus", {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e(), _vm.controls && !_vm.unit ? _c("span", {
    directives: [{
      name: "repeat-click",
      rawName: "v-repeat-click",
      value: _vm.increase,
      expression: "increase"
    }],
    staticClass: "tiny-numeric__increase",
    class: {
      "is-disabled": _vm.state.maxDisabled
    },
    attrs: {
      "role": "button"
    },
    on: {
      "keydown": function keydown($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "enter", 13, $event.key, "Enter")) return null;
        return _vm.increase.apply(null, arguments);
      }
    }
  }, [_c(_vm.state.controlsAtRight ? "icon-chevron-up" : "icon-plus", {
    tag: "component",
    staticClass: "tiny-svg-size"
  })], 1) : _vm._e(), _vm.unit && !_vm.hideUnit ? _c("div", {
    staticClass: "tiny-numeric__unit"
  }, [_vm._v(" " + _vm._s(_vm.unit) + " ")]) : _vm._e(), _c("div", {
    class: ["tiny-numeric__input", {
      "tiny-numeric__read-only": _vm.state.isDisplayOnly
    }, _vm.state.inputSize ? "tiny-input-" + _vm.state.inputSize : "", _vm.state.inputDisabled ? "is-disabled" : "", {
      "has-unit": _vm.unit && !_vm.hideUnit
    }, {
      "text-align-left": _vm.unit && !_vm.unitCenter
    }, {
      "tiny-numeric__controls-position": _vm.controlsPosition
    }]
  }, [_c("span", {
    staticClass: "tiny-numeric-display-only"
  }, [_vm.state.isDisplayOnly ? _c("span", {
    staticClass: "tiny-numeric-display-only__content"
  }, [_c("span", {
    staticClass: "tiny-numeric-display-only__value"
  }, [_vm._v(_vm._s(_vm.state.displayOnlyText))]), _vm.unit && !_vm.hideUnit && _vm.state.currentValue ? _c("span", {
    staticClass: "tiny-numeric-display-only__unit"
  }, [_vm._v(_vm._s(_vm.unit))]) : _vm.unit && !_vm.hideUnit ? _c("span", [_vm._v(_vm._s(_vm.unit))]) : _vm._e()]) : _vm._e(), _c("input", {
    ref: "input",
    class: ["tiny-numeric__input-inner", {
      "tiny-numeric__show-left": !_vm.controls && _vm.showLeft
    }],
    attrs: {
      "tabindex": _vm.tabindex,
      "placeholder": _vm.placeholder,
      "max": _vm.max,
      "min": _vm.min,
      "name": _vm.name,
      "aria-label": _vm.label
    },
    domProps: {
      "value": _vm.state.displayValue
    },
    on: {
      "keydown": [function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "up", 38, $event.key, ["Up", "ArrowUp"])) return null;
        $event.preventDefault();
        return _vm.increase.apply(null, arguments);
      }, function($event) {
        if (!$event.type.indexOf("key") && _vm._k($event.keyCode, "down", 40, $event.key, ["Down", "ArrowDown"])) return null;
        $event.preventDefault();
        return _vm.decrease.apply(null, arguments);
      }],
      "blur": _vm.handleBlur,
      "focus": _vm.handleFocus,
      "compositionend": _vm.handleInput,
      "input": _vm.handleInput,
      "change": _vm.handleInputChange
    }
  })])])])]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
